@@ -9,13 +9,15 @@ except (ImportError, SyntaxError):
 from .compat import urlparse
 from hashlib import sha1
 from .util import urlsafe_base64_encode, urlsafe_base64_decode
+from datetime import datetime
 import time
 
 class Auth(object):
 
-    """wcs auth 
+    """
+    wcs auth 
     
-    upload token & manager token
+    calculate upload token & manager token
 
     """
 
@@ -27,25 +29,24 @@ class Auth(object):
 
     def uploadtoken(self, putPolicy):
         """
+        input: Put Policy
         return: uploadtoken
         """
-
-        #current = int(round(time.time() * 1000))
- 
-        #if putPolicy['deadline'] == None or putPolicy['deadline'] < current:
-        #    raise ValueError("Invalid deadline")
+        current = int(time.mktime(datetime.now().timetuple())) * 1000
+        if 'deadline' not in putPolicy.keys() or putPolicy['deadline'] > current:
+            putPolicy['deadline'] = current + 7200000
 
         jsonputPolicy = json.dumps(putPolicy)
         #encodePutPolicy = base64.b64encode(jsonputPolicy)
         encodePutPolicy = urlsafe_base64_encode(jsonputPolicy)
-        tmp_encodePutPolicy = encodePutPolicy
         Sign = hmac.new(self.secret_key.encode('utf-8'), encodePutPolicy.encode('utf-8'), sha1)    
         #encodeSign = base64.b64encode(Sign.hexdigest())
         encodeSign = urlsafe_base64_encode(Sign.hexdigest())
-        return '{0}:{1}:{2}'.format(self.access_key, encodeSign, tmp_encodePutPolicy)
+        return '{0}:{1}:{2}'.format(self.access_key, encodeSign, encodePutPolicy)
 
     def managertoken(self, url, body=None):
         """
+        input: url & body(optional)
         return: managertoken
         """
         parsed_url = urlparse(url)
