@@ -3,13 +3,14 @@
 
 import os
 from os.path import expanduser
-
+import urllib
 import requests
 from requests_toolbelt import MultipartEncoder
 from wcs.commons.config import Config
 from wcs.commons.logme import debug,error
 from wcs.commons.util import https_check
 from requests.adapters import HTTPAdapter
+
 config_file = os.path.join(expanduser("~"), ".wcscfg")
 
 class SimpleUpload(object):
@@ -27,10 +28,10 @@ class SimpleUpload(object):
         global _session
         _session = session
 
-    def _gernerate_tool(self, f,token):
+    def _gernerate_tool(self, f,token ,key):
         fileds = {"token":token}
         url = "{0}/{1}/{2}".format(self.url,"file","upload")
-        fileds['file'] = ('filename', f, 'text/plain')
+        fileds['file'] = (urllib.quote(key.encode('utf-8')), f, 'text/plain')
         encoder = MultipartEncoder(fileds)
         headers = {"Content-Type":encoder.content_type}
         headers['Expect'] = '100-continue'
@@ -59,6 +60,9 @@ class SimpleUpload(object):
                     r = _session.post(url=url, headers=headers, data=encoder, verify=False,allow_redirects=False)
                 else:
                     r = _session.post(url=url, headers=headers, data=encoder, verify=False)
+        except requests.ConnectionError as conn_error:
+            debug('Url connection abnormal,please check url!')
+            return -1,conn_error
         except Exception as e:
             f.close()
             debug('Request url:' + url)
@@ -77,10 +81,10 @@ class SimpleUpload(object):
         except:           
             return r.status_code,r.text
 
-    def upload(self, filepath,token):
+    def upload(self, filepath,token ,key='filename'):
         if os.path.exists(filepath) and os.path.isfile(filepath):
             f = self._gernerate_content(filepath)
-            url,encoder,headers = self._gernerate_tool(f,token)
+            url,encoder,headers = self._gernerate_tool(f,token ,key)
             return self._upload(url,encoder,headers,f)
         else:
             error('Sorry ! Please input a existing file')
