@@ -1,11 +1,11 @@
 #!/usr/bin/python
 ## -*- coding: utf-8 -*-
 
-import base64
 import json
-import os,sys
-import tempfile
+import os
 import shutil
+import sys
+
 from wcs.commons.config import Config
 
 tmp_record_folder = Config.tmp_record_folder
@@ -70,4 +70,4 @@ class UploadProgressRecorder(object):
 
     def find_upload_record(self):
         return os.path.exists(self.record_folder)
-          
+
